@@ -32,14 +32,16 @@ EXPLANATION = ["This script runs a simple open source mining routine from the MU
                "                   ",
               "The script searches for hash-memorable keys",
               "This takes a while so the script is a little chatty, sorry.",
+              "There is a video explaining MUIDS at https://vimeo.com/397352413 too.",
               " ",
-              "A hash-memorable key is a unique identifier - which is to say a long randomly generated string representing a hexidecimal number",
+              "A hash-memorable key is a unique identifier.",
+              "Which is to say a long randomly generated string representing a hexidecimal number",
              "Such as 30599b096bc5751c311ea6e15e306c86",
              "Which might have been produced by a monkey sitting at 1/3 of a typewriter."
              " ",
-             "To explain MUIDs, we need a hash function that takes one hex number and turns it into another",
-             "Aside: a hash is a just a function that is almost impossible to invert. See https://en.wikipedia.org/wiki/Hash_function",
-             "We use the SHA-256 algorithm, which is completely standard and also used in bitcoin mining",
+             "Now a hash function takes one hex number and turns it into another",
+             "A hash is a just a function that is almost impossible to invert.",
+             "See https://en.wikipedia.org/wiki/Hash_function. We use SHA-256 truncated.",
              "The hash function might convert our key 30599b096bc5751c311ea6e15e306c86 ... ",
              "... into say 105ab1ef1ea6ab3e85743e028f42847e "
              "which looks like complete gibberish as well.",
@@ -57,16 +59,21 @@ EXPLANATION = ["This script runs a simple open source mining routine from the MU
               "You'll notice the astronomical coincidence.",
               "The characters spell 'Losable Flea' ",
               "Sort of.",
-              "Which means that the original key 30599b096bc5751c311ea6e15e306c86 might be said to be 'hash-memorable'.",
+              "Which means that the original key 30599b096bc5751c311ea6e15e306c86 is ...",
+              "'hash-memorable', so to speak.",
               "It is a MUID",
               "Like a UUID - if you are familiar with https://docs.python.org/3/library/uuid.html",
               "Only better, clearly.",
               "  ",
-             "This script does nothing but generate a vast number of random hexadecimal numbers in the hope that the hash function, when applied to them, accidentally produces a recognizable string",
-             "As noted, the strings aren't that recognizable unless you squint, and replace digits with letters (like 0->o, 7->t and so forth)",
+             "This script does nothing but generate a vast number of random hexadecimal numbers,",
+             "Eventually their hashes are recognizable strings although,",
+             "as noted, the strings aren't that recognizable unless you squint,",
+             "and replace digits with letters (like 0->o, 7->t and so forth).",
              "We've introduced the notion of readable hex, in this manner.",
              "The rules for coverting digits to letters are at https://pypi.org/project/muid/",
-             "And to save your eyesight we'll print the translation of the leading part of the hashed key, of course.",
+             "And to save your eyesight we'll print the translation,",
+             "which is to say your spirit animal."
+             "At times like this we all need a good spirit animal.",
              " ",
              "Why might hash-memorable keys be important?",
              "  ",
@@ -79,20 +86,24 @@ EXPLANATION = ["This script runs a simple open source mining routine from the MU
              "... hash-memorable keys can be used to create applications with one less join, as it were.",
              "If you write applications, you might appreciate that.",
              "  ",
-             "Now as it happens, this script ha already generated lots of MUIDs for you while simultaneously heating your home a little.",
+             "Now as it happens, this script has already generated lots of MUIDs for you,",
+             "while simultaneously heating your home a little.",
              "In a moment you will be able to see some of them and choose your spirit animal.",
              "There are 422,013 possible non de plumes.",
-             "If you do manage to generate an amusing spirit animal, by all means share it at https://www.quora.com/unanswered/What-are-the-most-amusing-hash-memorable-identifiers-you-have-generated ",
-            "Or vote there on your favourite hash-memorable key",
+             "If you do manage to generate an amusing spirit animal, by all means share it.",
+             "You can post at https://www.quora.com/What-are-the-most-amusing-hash-memorable-identifiers-you-have-generated ",
+             "Or vote there on your favourite hash-memorable key",
             "  ",
-            "But first ... there is a minor technical thing you need to know before choosing 'Collosal Oca' or 'Foldable Cat' over 'Bleachable Crab' ",
-            "Observe that the first two are length 11 and the latter length 14",
+            "But first ... there is a minor technical thing you need to know.",
+            "Before choosing 'Collosal Oca' or 'Foldable Cat' over 'Bleachable Crab' you should ...",
+            "... observe that the first two are length 11 and the latter length 14.",
             "So while Foldable Cat is unequivocally funnier than Bleachable Crab ...",
             "Bleachable Crab is about four thousand times harder to find than Foldable Cat",
             "And in a very important but yet mysterious application to be revealed on April 1st, 2020 ... ",
             "Bleachable Crab, or rather any key that hashes to it, will be four thousand times more valuable."   
             "  ",
-            "You are strongly advised to let the program run until Apr 1st and thereafter, so as to generate the longest possible MUID",
+            "You are strongly advised to let the program run until Apr 1st and thereafter,",
+             "so as to generate the longest possible MUID.",
             "Good MUIDs come to those who wait",
             "Check the length property of those that come out ...",
             "A length of 12 or higher is pretty useful ...",
